@@ -247,7 +247,7 @@ class XMLRPC(API):
         if max_count:
             filters['max_count'] = max_count
 
-        if archived:
+        if archived is not None:
             filters['archived'] = archived
 
         if msgid:
@@ -819,8 +819,8 @@ class REST(API):
             'context': obj['context'],
         }
 
-    def check_list(self, patch, user):
-        if not patch:
+    def check_list(self, patch_id, user):
+        if not patch_id:
             raise NotImplementedError(
                 'The REST API does not allow listing of all checks by '
                 'project; listing of checks requires a target patch'
@@ -831,19 +831,27 @@ class REST(API):
         if user is not None:
             filters['user'] = user
 
+        # this is icky, but alas we don't provide this information in the
+        # response
+        patch = self._detail(
+            'patches',
+            patch_id,
+        )
         checks = self._list(
             'patches',
             filters,
-            resource_id=patch,
+            resource_id=patch_id,
             subresource_type='checks',
         )
-        patch = self._detail(
-            'patches',
-            patch,
-        )
         return [self._check_to_dict(check, patch) for check in checks]
 
     def check_get(self, patch_id, check_id):
+        if not patch_id:
+            raise NotImplementedError(
+                'The REST API does not allow listing of all checks by '
+                'project; listing of checks requires a target patch'
+            )
+
         # this is icky, but alas we don't provide this information in the
         # response
         patch = self._detail(
@@ -852,7 +860,7 @@ class REST(API):
         )
         check = self._detail(
             'patches',
-            patch_id,
+            resource_id=patch_id,
             subresource_type='checks',
             subresource_id=check_id,
         )
